﻿using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Media;
using Arction.WPF.LightningChartUltimate;
using Arction.WPF.LightningChartUltimate.Axes;
using Arction.WPF.LightningChartUltimate.SeriesXY;
using Arction.WPF.LightningChartUltimate.Titles;
using Arction.WPF.LightningChartUltimate.Views.ViewXY;

namespace WpfApplication3
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            InitChart();
        }

        private void InitChart()
        {
            _chart.ViewXY.DropOldSeriesData = false;
            _chart.ViewXY.PointLineSeries = new PointLineSeriesObservableCollection();
            _chart.ViewXY.LineCollections = new LineCollectionObservableCollection();
            _chart.ViewXY.ZoomPanOptions.LeftMouseButtonAction = MouseButtonAction.Zoom;
            _chart.ViewXY.ZoomPanOptions.PanDirection = PanDirection.Horizontal;
            _chart.ViewXY.ZoomPanOptions.RectangleZoomDirection = RectangleZoomDirection.Horizontal;
            _chart.ViewXY.ZoomPanOptions.RightToLeftZoomAction = RightToLeftZoomAction.RevertAxisRanges;
            _chart.ViewXY.ZoomPanOptions.ZoomOutRectLine.Color = Colors.Transparent;
            _chart.ViewXY.ZoomPanOptions.ZoomOutRectFill = new Fill
            {
                Color = Colors.Transparent,
                GradientColor = Colors.Transparent
            };
            _chart.ViewXY.ZoomPanOptions.MouseWheelZooming = MouseWheelZooming.Horizontal;
            _chart.ViewXY.ZoomPanOptions.AxisMouseWheelAction = AxisMouseWheelAction.None;
            _chart.ViewXY.ZoomPanOptions.CtrlEnabled = false;
            _chart.ViewXY.ZoomPanOptions.ShiftEnabled = false;
            _chart.ViewXY.ZoomPanOptions.RectangleZoomLimitInsideGraph = false;
            _chart.ViewXY.AxisLayout.XAxisTitleAutoPlacement = false;
            _chart.ViewXY.AxisLayout.YAxisTitleAutoPlacement = false;


            _chart.Title = new ChartTitle
            {
               Visible = false
            };

            _chart.ChartRenderOptions.MultiCoreProcessing = MultiCoreProcessing.AllAvailableCores;
            _chart.ChartRenderOptions.DeviceType = RendererDeviceType.HardwareOnly;
            _chart.ChartRenderOptions.AntiAliasLevel = 0;

            //Setup x-axis
            AxisX axisX = _chart.ViewXY.XAxes[0];
            axisX.SetRange(0, 100);
            axisX.ScrollMode = XAxisScrollMode.None;
            axisX.ValueType = AxisValueType.Number;
            axisX.Visible = false;
            //Add point line series 
            PointLineSeries pls = new PointLineSeries(_chart.ViewXY,axisX, _chart.ViewXY.YAxes[0]);
            pls.PointsVisible = true;

            //Generate random data 
            Random rand = new Random();

            int iPointCount = 101;
            SeriesPoint[] aPoints = new SeriesPoint[iPointCount];

            for (int iPoint = 0; iPoint < iPointCount; iPoint++)
            {
                aPoints[iPoint].X = (double)iPoint;
                aPoints[iPoint].Y = 10.0 * rand.NextDouble();
            }
            //Assign the data for the point line series 
            pls.Points = aPoints;

            //Add the created point line series into PointLineSeries list 
            _chart.ViewXY.PointLineSeries.Add(pls);
            _chart.ViewXY.BeforeZooming += ViewXY_BeforeZooming;
        }

        void ViewXY_BeforeZooming(List<RangeChangeInfo> xRanges, List<RangeChangeInfo> yRanges, bool byWheel, ref bool cancel)
        {
            if (xRanges == null || xRanges.Count == 0 || yRanges == null || yRanges.Count == 0)
            {
                System.Diagnostics.Debug.WriteLine("Something missing");
            }

            bool bZooming = !(Equals(xRanges[0].NewMin, _chart.ViewXY.XAxes[0].Minimum) && Equals(xRanges[0].NewMax, _chart.ViewXY.XAxes[0].Maximum));
            if (bZooming)
                System.Diagnostics.Debug.WriteLine("Zooming");
            else
                System.Diagnostics.Debug.WriteLine("NOT Zooming");

        }
    }
}
